==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/CLOSINGPERIODID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for CLOSINGPERIODID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CLOSINGPERIODID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLOSINGDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEENTERED" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CLOSINGPERIODID_Type", propOrder = {
    "closingdate",
    "dateentered"
})
public class CLOSINGPERIODID_Type {

    @XmlElement(name = "CLOSINGDATE", required = true)
    protected DATETIME closingdate;
    @XmlElement(name = "DATEENTERED")
    protected DATETIME dateentered;

    /**
     * Gets the value of the closingdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCLOSINGDATE() {
        return closingdate;
    }

    /**
     * Sets the value of the closingdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCLOSINGDATE(DATETIME value) {
        this.closingdate = value;
    }

    /**
     * Gets the value of the dateentered property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEENTERED() {
        return dateentered;
    }

    /**
     * Sets the value of the dateentered property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEENTERED(DATETIME value) {
        this.dateentered = value;
    }

}

==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_fields/CLOSINGPERIODID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour CLOSINGPERIODID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CLOSINGPERIODID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLOSINGDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEENTERED" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CLOSINGPERIODID_Type", propOrder = {
    "closingdate",
    "dateentered"
})
public class CLOSINGPERIODID_Type {

    @XmlElement(name = "CLOSINGDATE", required = true)
    protected DATETIME closingdate;
    @XmlElement(name = "DATEENTERED")
    protected DATETIME dateentered;

    /**
     * Obtient la valeur de la propriété closingdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCLOSINGDATE() {
        return closingdate;
    }

    /**
     * Définit la valeur de la propriété closingdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCLOSINGDATE(DATETIME value) {
        this.closingdate = value;
    }

    /**
     * Obtient la valeur de la propriété dateentered.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEENTERED() {
        return dateentered;
    }

    /**
     * Définit la valeur de la propriété dateentered.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEENTERED(DATETIME value) {
        this.dateentered = value;
    }

}
